@@ -165,10 +165,10 @@ impl SymbolCache {
     }
 
     /// `path` should be a path of the form firefox.pdb/HEX/firefox.pdb
-    async fn get_pdb_impl(&self, path: &Path) -> Result<FileContents, Error> {
-        assert!(path.extension() == Some(OsStr::new("pdb")));
-        let mut compressed_path = path.to_owned();
-        compressed_path.set_extension("pd_");
+    async fn get_pdb_impl(&self, rel_path_uncompressed: &Path) -> Result<FileContents, Error> {
+        assert!(rel_path_uncompressed.extension() == Some(OsStr::new("pdb")));
+        let mut rel_path_compressed = rel_path_uncompressed.to_owned();
+        rel_path_compressed.set_extension("pd_");
 
         let mut persisted_cache_paths: Vec<PathBuf> = Vec::new();
         for entry in &self.symbol_path {
@@ -180,7 +180,12 @@ impl SymbolCache {
                     persisted_cache_paths.push(cache_path.clone());
                     let (_, parent_cache_paths) = persisted_cache_paths.split_last().unwrap();
                     if let Some(file_contents) = self
-                        .check_directory(cache_path, parent_cache_paths, path, &compressed_path)
+                        .check_directory(
+                            cache_path,
+                            parent_cache_paths,
+                            rel_path_uncompressed,
+                            &rel_path_compressed,
+                        )
                         .await?
                     {
                         return Ok(file_contents);
@@ -197,7 +202,12 @@ impl SymbolCache {
                         parent_cache_paths.push(cache_path.clone());
                         let (_, parent_cache_paths) = parent_cache_paths.split_last().unwrap();
                         if let Some(file_contents) = self
-                            .check_directory(cache_path, parent_cache_paths, path, &compressed_path)
+                            .check_directory(
+                                cache_path,
+                                parent_cache_paths,
+                                rel_path_uncompressed,
+                                &rel_path_compressed,
+                            )
                             .await?
                         {
                             return Ok(file_contents);
@@ -206,7 +216,12 @@ impl SymbolCache {
 
                     for url in urls {
                         if let Some(file_contents) = self
-                            .check_url(url, &parent_cache_paths, path, &compressed_path)
+                            .check_url(
+                                url,
+                                &parent_cache_paths,
+                                rel_path_uncompressed,
+                                &rel_path_compressed,
+                            )
                             .await?
                         {
                             return Ok(file_contents);
@@ -218,7 +233,12 @@ impl SymbolCache {
                         continue;
                     }
                     if let Some(file_contents) = self
-                        .check_directory(dir_path, &persisted_cache_paths, path, &compressed_path)
+                        .check_directory(
+                            dir_path,
+                            &persisted_cache_paths,
+                            rel_path_uncompressed,
+                            &rel_path_compressed,
+                        )
                         .await?
                     {
                         return Ok(file_contents);
@@ -250,20 +270,19 @@ impl SymbolCache {
         &self,
         dir: &Path,
         parent_cache_paths: &[PathBuf],
-        path: &Path,
-        compressed_path: &Path,
+        rel_path_uncompressed: &Path,
+        rel_path_compressed: &Path,
     ) -> Result<Option<FileContents>, Error> {
-        let full_candidate_path = dir.join(path);
-        let full_candidate_path_compr = dir.join(&compressed_path);
+        let full_candidate_path = dir.join(rel_path_uncompressed);
+        let full_candidate_path_compr = dir.join(&rel_path_compressed);
 
-        let (rel_path, abs_path, is_compressed) =
-            if self.check_file_exists(&full_candidate_path).await {
-                (path, full_candidate_path, false)
-            } else if self.check_file_exists(&full_candidate_path_compr).await {
-                (compressed_path, full_candidate_path_compr, true)
-            } else {
-                return Ok(None);
-            };
+        let (abs_path, is_compressed) = if self.check_file_exists(&full_candidate_path).await {
+            (full_candidate_path, false)
+        } else if self.check_file_exists(&full_candidate_path_compr).await {
+            (full_candidate_path_compr, true)
+        } else {
+            return Ok(None);
+        };
 
         // We found a file. Yay!
 
@@ -274,9 +293,9 @@ impl SymbolCache {
                 // We have at least one cache, and the file is compressed.
                 // Copy the compressed file to the mid-level caches, and uncompress the file
                 // into the bottom-most cache.
-                self.copy_file_to_caches(rel_path, &abs_path, mid_level_caches)
+                self.copy_file_to_caches(rel_path_compressed, &abs_path, mid_level_caches)
                     .await;
-                self.extract_to_file_in_cache(&mmap[..], path, bottom_most_cache)
+                self.extract_to_file_in_cache(&mmap[..], rel_path_uncompressed, bottom_most_cache)
                     .await?
             } else {
                 // We have no cache. Extract it into memory.
@@ -297,19 +316,19 @@ impl SymbolCache {
         &self,
         url: &str,
         parent_cache_paths: &[PathBuf],
-        path: &Path,
-        compressed_path: &Path,
+        rel_path_uncompressed: &Path,
+        rel_path_compressed: &Path,
     ) -> Result<Option<FileContents>, Error> {
-        let full_candidate_url = url_join(url, path.components());
-        let full_candidate_url_compr = url_join(url, compressed_path.components());
-        let (rel_path, bytes, is_compressed) =
-            match self.get_bytes_from_url(&full_candidate_url_compr).await {
-                Some(bytes) => (compressed_path, bytes, true),
-                None => match self.get_bytes_from_url(&full_candidate_url).await {
-                    Some(bytes) => (path, bytes, false),
-                    None => return Ok(None),
-                },
-            };
+        let full_candidate_url = url_join(url, rel_path_uncompressed.components());
+        let full_candidate_url_compr = url_join(url, rel_path_compressed.components());
+        let (bytes, is_compressed) = match self.get_bytes_from_url(&full_candidate_url_compr).await
+        {
+            Some(bytes) => (bytes, true),
+            None => match self.get_bytes_from_url(&full_candidate_url).await {
+                Some(bytes) => (bytes, false),
+                None => return Ok(None),
+            },
+        };
 
         // We have a file!
         let file_contents = if is_compressed {
@@ -321,12 +340,12 @@ impl SymbolCache {
                     mid_level_caches.split_first()
                 {
                     if let Ok(abs_compressed_path) = self
-                        .save_file_to_cache(&bytes[..], rel_path, one_mid_level_cache)
+                        .save_file_to_cache(&bytes[..], rel_path_compressed, one_mid_level_cache)
                         .await
                     {
                         let _ = self
                             .copy_file_to_caches(
-                                rel_path,
+                                rel_path_compressed,
                                 &abs_compressed_path,
                                 other_mid_level_caches,
                             )
@@ -334,7 +353,7 @@ impl SymbolCache {
                     }
                 }
                 let uncompressed_path = self
-                    .extract_to_file_in_cache(&bytes[..], rel_path, bottom_most_cache)
+                    .extract_to_file_in_cache(&bytes[..], rel_path_uncompressed, bottom_most_cache)
                     .await?;
                 let file = tokio::fs::File::open(&uncompressed_path).await?;
                 FileContents::Mmap(unsafe { memmap2::MmapOptions::new().map(&file)? })
@@ -349,11 +368,15 @@ impl SymbolCache {
                 // We have at least one cache, and the file is NOT compressed.
                 // Save the file to the bottom-most cache, and copy it into the mid-level caches.
                 if let Ok(abs_compressed_path) = self
-                    .save_file_to_cache(&bytes[..], rel_path, bottom_most_cache)
+                    .save_file_to_cache(&bytes[..], rel_path_uncompressed, bottom_most_cache)
                     .await
                 {
                     let _ = self
-                        .copy_file_to_caches(rel_path, &abs_compressed_path, mid_level_caches)
+                        .copy_file_to_caches(
+                            rel_path_uncompressed,
+                            &abs_compressed_path,
+                            mid_level_caches,
+                        )
                         .await;
                 }
             } else {
